@@ -18,7 +18,7 @@ PGLogit <- function(formula, weights = 1, data = parent.frame(), n.samples, n.om
     ####################################################
     if(missing(formula)){stop("error: formula must be specified")}
     
-    if(class(formula) == "formula"){
+    if(is(formula, "formula")){
         
         holder <- parseFormula(formula, data)
         y <- as.vector(holder[[1]])
