@@ -23,7 +23,7 @@ spNNGP <- function(formula, data = parent.frame(), coords, method = "response",
     ####################################################
     if(missing(formula)){stop("error: formula must be specified")}
     
-    if(class(formula) == "formula"){
+    if(is(formula, "formula")){
         
         holder <- parseFormula(formula, data)
         y <- as.vector(holder[[1]])
